@@ -1,8 +1,9 @@
 from pathlib import Path
 from flask import Flask, send_from_directory, render_template
-from jellyfin_accounts import config, app, g, css, data_store
+
+from jellyfin_accounts import app, g, css_file, data_store
 from jellyfin_accounts import web_log as log
-from jellyfin_accounts.web_api import checkInvite, validator
+from jellyfin_accounts.web_api import config, checkInvite, validator
 
 
 @app.errorhandler(404)
@@ -10,9 +11,8 @@ def page_not_found(e):
     return (
         render_template(
             "404.html",
-            css_href=css["href"],
-            css_integrity=css["integrity"],
-            css_crossorigin=css["crossorigin"],
+            bs5=config.getboolean("ui", "bs5"),
+            css_file=css_file,
             contactMessage=config["ui"]["contact_message"],
         ),
         404,
@@ -24,9 +24,8 @@ def admin():
     # return app.send_static_file('admin.html')
     return render_template(
         "admin.html",
-        css_href=css["href"],
-        css_integrity=css["integrity"],
-        css_crossorigin=css["crossorigin"],
+        bs5=config.getboolean("ui", "bs5"),
+        css_file=css_file,
         contactMessage="",
         email_enabled=config.getboolean("invite_emails", "enabled"),
     )
@@ -35,13 +34,22 @@ def admin():
 @app.route("/<path:path>")
 def static_proxy(path):
     if "html" not in path:
+        if "admin.js" in path:
+            if config.getboolean("ui", "bs5"):
+                bsVersion = 5
+            else:
+                bsVersion = 4
+            return (
+                render_template("admin.js", bsVersion=bsVersion),
+                200,
+                {"Content-Type": "text/javascript"},
+            )
         return app.send_static_file(path)
     return (
         render_template(
             "404.html",
-            css_href=css["href"],
-            css_integrity=css["integrity"],
-            css_crossorigin=css["crossorigin"],
+            bs5=config.getboolean("ui", "bs5"),
+            css_file=css_file,
             contactMessage=config["ui"]["contact_message"],
         ),
         404,
@@ -58,9 +66,8 @@ def inviteProxy(path):
             email = ""
         return render_template(
             "form.html",
-            css_href=css["href"],
-            css_integrity=css["integrity"],
-            css_crossorigin=css["crossorigin"],
+            bs5=config.getboolean("ui", "bs5"),
+            css_file=css_file,
             contactMessage=config["ui"]["contact_message"],
             helpMessage=config["ui"]["help_message"],
             successMessage=config["ui"]["success_message"],
@@ -76,8 +83,7 @@ def inviteProxy(path):
         log.debug("Attempted use of invalid invite")
         return render_template(
             "invalidCode.html",
-            css_href=css["href"],
-            css_integrity=css["integrity"],
-            css_crossorigin=css["crossorigin"],
+            bs5=config.getboolean("ui", "bs5"),
+            css_file=css_file,
             contactMessage=config["ui"]["contact_message"],
         )
